@@ -19,8 +19,8 @@ class API(object):
         '''
         self.username = username
         self.password = password
-        self.domain = 'https://manager.sigmarisk.com.au/api/'
-        self.domain_ws = 'wss://manager.sigmarisk.com.au/api/PriceStream/'
+        self.domain = 'https://manager.sigmarisk.com.au:34335/api/'
+        self.domain_ws = 'wss://manager.sigmarisk.com.au:34335/api/PriceStream/'
         self.refresh_token(username,password)
         self.price = {}
         self.bars = {}
@@ -60,7 +60,6 @@ class API(object):
         
         # print(self.token)
         response = requests.post(link, data = json.dumps(params), headers = {'TOKEN': f'{self.token}','Content-Type' : 'application/json; charset=utf-8'})
-        print(response.json())
         return response.json()
 
     def close_order(self, ticket, lots = None, price = None):
@@ -82,7 +81,6 @@ class API(object):
             params = {"ticket":ticket,"lots":lots,"price":price}
         link = self.domain + 'OrderClose'
         response = requests.post(link,data = json.dumps(params), headers = {'TOKEN': f'{self.token}','Content-Type' : 'application/json; charset=utf-8'})
-        print(response.json())
         return response.json()
 
     def trades_history_by_datetime(self, start_time, end_time):
